@@ -7,24 +7,28 @@ use vars qw[@ISA $VERSION ];
 use POSIX qw[setsid ];
 
 @ISA     = qw[Mail::POPRelay ];
-$VERSION = '0.1.0';
+$VERSION = '0.1.1';
 
 
-# trap signal handling
+# trap signals
 # ---------
 sub __setupSignals {
 	my $self = shift;
 
-	$SIG{'TERM'} = sub { $self->wipeRelayDirectory();  };
-	$SIG{'KILL'} = sub { $self->wipeRelayDirectory();  };
-	$SIG{'HUP'}  = sub { $self->cleanRelayDirectory(); };
+	$SIG{'TERM'} = sub { $self->wipeRelayDirectory(); $self->generateRelayFile(); };
+	$SIG{'KILL'} = sub { $self->wipeRelayDirectory(); $self->generateRelayFile(); };
+	$SIG{'HUP'}  = sub { 
+				$self->initWithConfigFile($self->{'configFile'}); 
+				$self->cleanRelayDirectory();
+				$self->generateRelayFile(); 
+	};
 }
 
 
 # daemonize
 # ---------
 sub init {
-	my $self = Mail::POPRelay::init(@_);
+	my $self = Mail::POPRelay::initWithConfigFile(@_);
 
 	defined(my $pid = fork()) or die "Unable to fork: $!";
 	if ($pid) {
@@ -32,7 +36,7 @@ sub init {
 		return $pid;
 	} else {
 		# sibling
-		chdir('/')              or die "Can't chdir to /: $!";
+		#chdir('/')              or die "Can't chdir to /: $!";
 		setsid()                or die "Can't start new session: $!";
 		open STDERR, '>&STDOUT' or die "Can't dup stdout: $!";
 
@@ -58,14 +62,13 @@ sub __mainLoop {
 	my $line;
 	while (defined($line = $fileTail->read())) {
 		if ($line =~ m|$self->{'mailLogRegExp'}|) {
-			print "o Removing addresses\n" if $Mail::POPRelay::DEBUG;
-			$self->cleanRelayDirectory();
-			print "o Adding address\n" if $Mail::POPRelay::DEBUG;
-			$self->addRelayAddress($1, $2);
-			print "o Generating relay file.\n" if $Mail::POPRelay::DEBUG;
-			$self->generateRelayFile();
+			# save processing cycles and exit early if possible
+			$self->generateRelayFile()
+				if ($self->cleanRelayDirectory() || $self->addRelayAddress($1, $2));
 		}
 	}
+	$self->wipeRelayDirectory(); 
+	$self->generateRelayFile();
 }
 
 
@@ -93,10 +96,30 @@ The daemon class of POPRelay.
 die().  Will write to syslog eventually.
 
 
+=head1 SIGNALS
+
+=over 8
+
+Described below are the actions taken for recieving various signals.
+
+=item HUP
+
+The config file is reloaded and the relay file is regenerated.
+
+=item KILL
+
+The relay file is wiped clean.
+
+=item TERM
+
+The relay file is wiped clean.
+
+=back
+
 =head1 CONTRIBUTE
 
-If you feel compelled to write a subclass of POPRelay::Daemon, please let
-me know so that it may be reviewed for addition to the CVS repository!
+If you feel compelled to write a subclass of POPRelay::Daemon, please sent
+it to the author for incorporation into the next release.
 
 
 =head1 AUTHOR
@@ -106,8 +129,8 @@ Keith Hoerling <keith@hoerling.com>
 
 =head1 SEE ALSO
 
-Mail::POPRelay(3pm), poprelay_cleanup(1p), poprelay_ipop3d(1p).
+Mail::POPRelay(3pm), poprelay_cleanup(1p).
 
 =cut
 
-# $Id: Daemon.pm,v 1.3 2001/11/25 00:37:27 keith Exp $
+# $Id: Daemon.pm,v 1.5 2002/02/13 04:18:53 keith Exp $
